@@ -71,8 +71,8 @@ GoogleFetcherDialog::GoogleFetcherDialog(const TQString &name,
     combo->insertItem(i18n("Large"));
     combo->insertItem(i18n("Very Large"));
     combo->setCurrentItem(0);
-    connect(combo, TQT_SIGNAL(activated(int)), this, TQT_SLOT(imgSizeChanged(int)));
-    connect(m_iconWidget, TQT_SIGNAL( executed(TQIconViewItem*) ), this, TQT_SLOT(slotOk()));
+    connect(combo, TQ_SIGNAL(activated(int)), this, TQ_SLOT(imgSizeChanged(int)));
+    connect(m_iconWidget, TQ_SIGNAL( executed(TQIconViewItem*) ), this, TQ_SLOT(slotOk()));
 
     imgSize->adjustSize();
     setMainWidget(mainBox);
@@ -216,9 +216,9 @@ CoverIconViewItem::CoverIconViewItem(TQIconView *parent, const GoogleImage &imag
     // Start downloading the image.
 
     m_job = TDEIO::get(image.thumbURL(), false, false);
-    connect(m_job, TQT_SIGNAL(result(TDEIO::Job *)), this, TQT_SLOT(imageResult(TDEIO::Job *)));
-    connect(m_job, TQT_SIGNAL(data(TDEIO::Job *, const TQByteArray &)),
-            this, TQT_SLOT(imageData(TDEIO::Job *, const TQByteArray &)));
+    connect(m_job, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(imageResult(TDEIO::Job *)));
+    connect(m_job, TQ_SIGNAL(data(TDEIO::Job *, const TQByteArray &)),
+            this, TQ_SLOT(imageData(TDEIO::Job *, const TQByteArray &)));
 }
 
 CoverIconViewItem::~CoverIconViewItem()
