@@ -30,7 +30,7 @@ class KURL;
 
 class GoogleFetcherDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -81,7 +81,7 @@ namespace TDEIO
 
 class CoverIconViewItem : public TQObject, public TDEIconViewItem
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
