@@ -122,8 +122,8 @@ DvbPanel::DvbPanel( TQWidget *parent, TQObject *objParent, const char *name ) :
 	iconView->setVScrollBarMode( TQScrollView::AlwaysOff );
 	iconView->setHScrollBarMode( TQScrollView::AlwaysOff );
 	iconView->horizontalScrollBar()->setFixedHeight( 0 );
-	connect( iconView, TQT_SIGNAL(rightButtonPressed(TQIconViewItem*,const TQPoint&)), this, TQT_SLOT(catContextMenu(TQIconViewItem*,const TQPoint&)) );
-	connect( iconView, TQT_SIGNAL(clicked(TQIconViewItem*)), this, TQT_SLOT(catSelected(TQIconViewItem*)) );
+	connect( iconView, TQ_SIGNAL(rightButtonPressed(TQIconViewItem*,const TQPoint&)), this, TQ_SLOT(catContextMenu(TQIconViewItem*,const TQPoint&)) );
+	connect( iconView, TQ_SIGNAL(clicked(TQIconViewItem*)), this, TQ_SLOT(catSelected(TQIconViewItem*)) );
 	iconView->setArrangement(TQIconView::TopToBottom);
 	iconView->setMargin(0);
 	iconView->setSpacing(0);
@@ -183,10 +183,10 @@ DvbPanel::DvbPanel( TQWidget *parent, TQObject *objParent, const char *name ) :
 	channelsCb = new DListView( panel );
 	channelsCb->setHScrollBarMode( TQListView::AlwaysOff );
 	//channelsCb->setPaletteBackgroundColor( TQColor(255,255,200) );
-	connect( channelsCb, TQT_SIGNAL(itemRenamed(TQListViewItem*)), this, TQT_SLOT(channelNumberChanged(TQListViewItem*)) );
-	connect( channelsCb, TQT_SIGNAL(doubleClicked(TQListViewItem*)), this, TQT_SLOT(channelSelected(TQListViewItem*)) );
-	connect( channelsCb, TQT_SIGNAL(clicked(TQListViewItem*)), this, TQT_SLOT(channelClicked(TQListViewItem*)) );
-	connect( channelsCb, TQT_SIGNAL(contextMenuRequested(TQListViewItem*,const TQPoint&,int)), this, TQT_SLOT(channelPopup(TQListViewItem*,const TQPoint&,int)) );
+	connect( channelsCb, TQ_SIGNAL(itemRenamed(TQListViewItem*)), this, TQ_SLOT(channelNumberChanged(TQListViewItem*)) );
+	connect( channelsCb, TQ_SIGNAL(doubleClicked(TQListViewItem*)), this, TQ_SLOT(channelSelected(TQListViewItem*)) );
+	connect( channelsCb, TQ_SIGNAL(clicked(TQListViewItem*)), this, TQ_SLOT(channelClicked(TQListViewItem*)) );
+	connect( channelsCb, TQ_SIGNAL(contextMenuRequested(TQListViewItem*,const TQPoint&,int)), this, TQ_SLOT(channelPopup(TQListViewItem*,const TQPoint&,int)) );
 	channelsCb->setItemsRenameable( true );
 	channelsCb->addColumn( i18n("Number") );
 	channelsCb->addColumn( i18n("Name") );
@@ -254,25 +254,25 @@ DvbPanel::DvbPanel( TQWidget *parent, TQObject *objParent, const char *name ) :
 	setXMLFile("kaffeinedvb.rc");
 	setupActions();
 
-	connect( this, TQT_SIGNAL(zap(ChannelDesc*)), TQT_SLOT(dvbZap(ChannelDesc*)) );
-	connect( configBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(showConfigDialog()));
-	connect( recallBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(recallZap()));
+	connect( this, TQ_SIGNAL(zap(ChannelDesc*)), TQ_SLOT(dvbZap(ChannelDesc*)) );
+	connect( configBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(showConfigDialog()));
+	connect( recallBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(recallZap()));
 
-	connect( recordBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(setRecord()) );
-	connect( broadcastBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(setBroadcast()) );
-	connect( infoBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(showEvents()) );
-	connect( channelsBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(scanner()) );
-	connect( dateBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(showTimers()) );
-	connect( osdBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(dvbOSD()));
-	connect( searchBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(resetSearch()) );
-	connect(searchLE, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(searchChannel(const TQString&)));
+	connect( recordBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(setRecord()) );
+	connect( broadcastBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(setBroadcast()) );
+	connect( infoBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(showEvents()) );
+	connect( channelsBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(scanner()) );
+	connect( dateBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(showTimers()) );
+	connect( osdBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(dvbOSD()));
+	connect( searchBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(resetSearch()) );
+	connect(searchLE, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(searchChannel(const TQString&)));
 
-	connect( &timersTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(checkTimers()) );
-	connect( &osdTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(resetOSD()) );
-	connect( &showOsdTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(dvbOSD()) );
-	connect( &tuningTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(setTuning()) );
-	connect( &stopTuningTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(setTuning()) );
-	connect( &diskTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(diskStatus()) );
+	connect( &timersTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(checkTimers()) );
+	connect( &osdTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(resetOSD()) );
+	connect( &showOsdTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(dvbOSD()) );
+	connect( &tuningTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(setTuning()) );
+	connect( &stopTuningTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(setTuning()) );
+	connect( &diskTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(diskStatus()) );
 
 	setConfig();
 
@@ -425,7 +425,7 @@ bool DvbPanel::execTarget( const TQString &target )
 			return true;
 		}
 		emit showMe( this );
-		TQTimer::singleShot( 100, this, TQT_SLOT(playLastChannel()) );
+		TQTimer::singleShot( 100, this, TQ_SLOT(playLastChannel()) );
 		return true;
 	}
 	return false;
@@ -435,19 +435,19 @@ bool DvbPanel::execTarget( const TQString &target )
 
 void DvbPanel::setupActions()
 {
-	new TDEAction(i18n("OSD Next Channel"), "go-next", CTRL+SHIFT+Key_W, this, TQT_SLOT(dvbOSDNext()), actionCollection(), "dvb_browse_next");
-	new TDEAction(i18n("OSD Previous Channel"), "go-previous", CTRL+SHIFT+Key_Q, this, TQT_SLOT(dvbOSDPrev()), actionCollection(),"dvb_browse_prev");
-	new TDEAction(i18n("OSD Zap"), "ok", CTRL+SHIFT+Key_E, this, TQT_SLOT(dvbOSDZap()), actionCollection(), "dvb_browse_zap");
-	new TDEAction(i18n("OSD Next Event"), "go-down", CTRL+SHIFT+Key_S, this, TQT_SLOT(dvbOSDAdvance()), actionCollection(), "dvb_browse_advance");
-	new TDEAction(i18n("OSD Previous Event"), "go-up", CTRL+SHIFT+Key_A, this, TQT_SLOT(dvbOSDRetreat()), actionCollection(), "dvb_browse_retreat");
-	new TDEAction(i18n("Instant Record"), "document-save", 0, this, TQT_SLOT(setRecord()), actionCollection(), "dvb_instant_record");
-	new TDEAction(i18n("Recall"), "reload", CTRL+SHIFT+Key_Z, this, TQT_SLOT(recallZap()), actionCollection(), "dvb_recall");
-	new TDEAction(i18n("Show OSD"), "application-vnd.tde.info", Key_O, this, TQT_SLOT(dvbOSD()), actionCollection(), "dvb_show_osd");
-	new TDEAction(i18n("EPG..."), "view_text", Key_G, this, TQT_SLOT(showEvents()), actionCollection(), "dvb_show_epg");
-	new TDEAction(i18n("Timers..."), "date", Key_T, this, TQT_SLOT(showTimers()), actionCollection(), "dvb_show_timers");
-	new TDEAction(i18n("Broadcasting..."), "network_local", Key_B, this, TQT_SLOT(setBroadcast()), actionCollection(), "dvb_show_broadcast");
-	new TDEAction(i18n("Channels..."), "kdvbtv", Key_C, this, TQT_SLOT(scanner()), actionCollection(), "dvb_channels");
-	new TDEAction(i18n("Configure DVB..."), "configure", CTRL|Key_C, this, TQT_SLOT(showConfigDialog()), actionCollection(), "dvb_config");
+	new TDEAction(i18n("OSD Next Channel"), "go-next", CTRL+SHIFT+Key_W, this, TQ_SLOT(dvbOSDNext()), actionCollection(), "dvb_browse_next");
+	new TDEAction(i18n("OSD Previous Channel"), "go-previous", CTRL+SHIFT+Key_Q, this, TQ_SLOT(dvbOSDPrev()), actionCollection(),"dvb_browse_prev");
+	new TDEAction(i18n("OSD Zap"), "ok", CTRL+SHIFT+Key_E, this, TQ_SLOT(dvbOSDZap()), actionCollection(), "dvb_browse_zap");
+	new TDEAction(i18n("OSD Next Event"), "go-down", CTRL+SHIFT+Key_S, this, TQ_SLOT(dvbOSDAdvance()), actionCollection(), "dvb_browse_advance");
+	new TDEAction(i18n("OSD Previous Event"), "go-up", CTRL+SHIFT+Key_A, this, TQ_SLOT(dvbOSDRetreat()), actionCollection(), "dvb_browse_retreat");
+	new TDEAction(i18n("Instant Record"), "document-save", 0, this, TQ_SLOT(setRecord()), actionCollection(), "dvb_instant_record");
+	new TDEAction(i18n("Recall"), "reload", CTRL+SHIFT+Key_Z, this, TQ_SLOT(recallZap()), actionCollection(), "dvb_recall");
+	new TDEAction(i18n("Show OSD"), "application-vnd.tde.info", Key_O, this, TQ_SLOT(dvbOSD()), actionCollection(), "dvb_show_osd");
+	new TDEAction(i18n("EPG..."), "view_text", Key_G, this, TQ_SLOT(showEvents()), actionCollection(), "dvb_show_epg");
+	new TDEAction(i18n("Timers..."), "date", Key_T, this, TQ_SLOT(showTimers()), actionCollection(), "dvb_show_timers");
+	new TDEAction(i18n("Broadcasting..."), "network_local", Key_B, this, TQ_SLOT(setBroadcast()), actionCollection(), "dvb_show_broadcast");
+	new TDEAction(i18n("Channels..."), "kdvbtv", Key_C, this, TQ_SLOT(scanner()), actionCollection(), "dvb_channels");
+	new TDEAction(i18n("Configure DVB..."), "configure", CTRL|Key_C, this, TQ_SLOT(showConfigDialog()), actionCollection(), "dvb_config");
 }
 
 
@@ -1059,11 +1059,11 @@ void DvbPanel::setConfig()
 		d = new DvbStream( dvbConfig->devList.at(i), dvbConfig->defaultCharset, &events );
 		d->setPlug( plug );
 		dvb.append( d );
-		connect( d, TQT_SIGNAL(shifting(bool)), this, TQT_SLOT(setShiftLed(bool)) );
-		connect( d, TQT_SIGNAL(isBroadcasting(bool)), this, TQT_SLOT(setBroadcastLed(bool)) );
-		connect( d, TQT_SIGNAL(timerEnded(RecTimer*)), this, TQT_SLOT(killTimer(RecTimer*)) );
-		connect( d, TQT_SIGNAL(isRecording(bool)), this, TQT_SLOT(setRecordLed(bool)) );
-		connect( d, TQT_SIGNAL(playDvb()), this, TQT_SLOT(pipeOpened()) );
+		connect( d, TQ_SIGNAL(shifting(bool)), this, TQ_SLOT(setShiftLed(bool)) );
+		connect( d, TQ_SIGNAL(isBroadcasting(bool)), this, TQ_SLOT(setBroadcastLed(bool)) );
+		connect( d, TQ_SIGNAL(timerEnded(RecTimer*)), this, TQ_SLOT(killTimer(RecTimer*)) );
+		connect( d, TQ_SIGNAL(isRecording(bool)), this, TQ_SLOT(setRecordLed(bool)) );
+		connect( d, TQ_SIGNAL(playDvb()), this, TQ_SLOT(pipeOpened()) );
 	}
 	fifoName = TDEGlobal::dirs()->saveLocation("tmp")+".kaxtv.ts";
 	TQFile f( fifoName );
@@ -1112,9 +1112,9 @@ loop:
 	for ( i=0; i<(int)dvb.count(); i++ )
 		dvb.at(i)->probeCam();
 	DvbConfigDialog dlg( this, dvbConfig, mainWidget, plug );
-	connect( dlg.dumpBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(dumpEvents()) );
+	connect( dlg.dumpBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(dumpEvents()) );
 	ret = dlg.exec();
-	disconnect( dlg.dumpBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(dumpEvents()) );
+	disconnect( dlg.dumpBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(dumpEvents()) );
 	if ( ret==DvbConfigDialog::Rejected )
 		return;
 	rtp->setSocket( dvbConfig->broadcastAddress, dvbConfig->broadcastPort, dvbConfig->senderPort );
@@ -1606,14 +1606,14 @@ void DvbPanel::showTimers()
 
 	timersDialog = new KRecord( list, &timers, mainWidget, dvbConfig->timerSize );
 	for ( i=0; i<(int)dvb.count(); i++ ) {
-		connect( timersDialog, TQT_SIGNAL(updateTimer(RecTimer*,int)), dvb.at(i), TQT_SLOT(updateTimer(RecTimer*,int)) );
+		connect( timersDialog, TQ_SIGNAL(updateTimer(RecTimer*,int)), dvb.at(i), TQ_SLOT(updateTimer(RecTimer*,int)) );
 	}
-	connect( this, TQT_SIGNAL(timersChanged()), timersDialog, TQT_SLOT(refresh()) );
+	connect( this, TQ_SIGNAL(timersChanged()), timersDialog, TQ_SLOT(refresh()) );
 	timersDialog->exec();
 	for ( i=0; i<(int)dvb.count(); i++ ) {
-		disconnect( timersDialog, TQT_SIGNAL(updateTimer(RecTimer*,int)), dvb.at(i), TQT_SLOT(updateTimer(RecTimer*,int)) );
+		disconnect( timersDialog, TQ_SIGNAL(updateTimer(RecTimer*,int)), dvb.at(i), TQ_SLOT(updateTimer(RecTimer*,int)) );
 	}
-	disconnect( this, TQT_SIGNAL(timersChanged()), timersDialog, TQT_SLOT(refresh()) );
+	disconnect( this, TQ_SIGNAL(timersChanged()), timersDialog, TQ_SLOT(refresh()) );
 	dvbConfig->timerSize = timersDialog->size();
 	delete timersDialog;
 	timersDialog = 0;
@@ -1632,7 +1632,7 @@ int DvbPanel::getSNR( int device )
 
 void DvbPanel::dvbNewTimer( TQString name, TQString channel, TQString datetime, TQString duration )
 {
-	newTimer( channel, name, TQDateTime::fromString( datetime, Qt::ISODate ), TQTime::fromString( duration ), false );
+	newTimer( channel, name, TQDateTime::fromString( datetime, TQt::ISODate ), TQTime::fromString( duration ), false );
 }
 
 
@@ -1692,12 +1692,12 @@ void DvbPanel::showEvents()
 {
 	events.doClean( false );
 	KEvents dlg( &channels, &dvb, &events, mainWidget, dvbConfig->epgSize );
-	connect( &dlg, TQT_SIGNAL(addTimer(TQString,TQString,TQDateTime,TQTime)), this, TQT_SLOT(newTimer(TQString,TQString,TQDateTime,TQTime)) );
-	connect( &dlg, TQT_SIGNAL(zapTo(const TQString &)), this, TQT_SLOT(channelSelected(const TQString &)) );
+	connect( &dlg, TQ_SIGNAL(addTimer(TQString,TQString,TQDateTime,TQTime)), this, TQ_SLOT(newTimer(TQString,TQString,TQDateTime,TQTime)) );
+	connect( &dlg, TQ_SIGNAL(zapTo(const TQString &)), this, TQ_SLOT(channelSelected(const TQString &)) );
 	dlg.exec();
 	dvbConfig->epgSize = dlg.size();
-	disconnect( &dlg, TQT_SIGNAL(addTimer(TQString,TQString,TQDateTime,TQTime)), this, TQT_SLOT(newTimer(TQString,TQString,TQDateTime,TQTime)) );
-	disconnect( &dlg, TQT_SIGNAL(zapTo(const TQString &)), this, TQT_SLOT(channelSelected(const TQString &)) );
+	disconnect( &dlg, TQ_SIGNAL(addTimer(TQString,TQString,TQDateTime,TQTime)), this, TQ_SLOT(newTimer(TQString,TQString,TQDateTime,TQTime)) );
+	disconnect( &dlg, TQ_SIGNAL(zapTo(const TQString &)), this, TQ_SLOT(channelSelected(const TQString &)) );
 	events.doClean( true );
 }
 
@@ -1844,7 +1844,7 @@ void DvbPanel::playLastChannel()
 		}
 	}
 	if ( ! list.count() ) {
-		TQTimer::singleShot( 2000, this, TQT_SLOT(playLastChannel()) );
+		TQTimer::singleShot( 2000, this, TQ_SLOT(playLastChannel()) );
 		return;
 	}
 	d = getWorkingDvb( MODE_BROADCAST, list.at(0) );
@@ -1868,7 +1868,7 @@ void DvbPanel::playLastChannel()
 	else
 		fprintf( stderr, "Can't start broadcasting.\n");
 
-	TQTimer::singleShot( 2000, this, TQT_SLOT(playLastChannel()) );
+	TQTimer::singleShot( 2000, this, TQ_SLOT(playLastChannel()) );
 	return;*/
 
 
@@ -2055,7 +2055,7 @@ void DvbPanel::finalZap( DvbStream *d, ChannelDesc *chan )
 		recallChannel = dvbConfig->lastChannel;
 		dvbConfig->lastChannel = chan->num;
 	}
-	//TQTimer::singleShot( 3000, this, TQT_SLOT(playLastChannel()) );
+	//TQTimer::singleShot( 3000, this, TQ_SLOT(playLastChannel()) );
 }
 
 
@@ -2594,7 +2594,7 @@ bool DvbPanel::getTimerList()
 			t->channel = s.left( pos );
 			s = s.right( s.length()-pos-1 );
 			pos = s.find("|");
-			t->begin = TQDateTime::fromString( s.left( pos ), Qt::ISODate );
+			t->begin = TQDateTime::fromString( s.left( pos ), TQt::ISODate );
 			s = s.right( s.length()-pos-1 );
 			pos = s.find("|");
 			t->duration = TQTime::fromString( s.left( pos ) );
