@@ -55,7 +55,7 @@ class KaffeineDvbPlugin;
 
 class DListView : public TDEListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	DListView( TQWidget *parent );
@@ -82,7 +82,7 @@ private:
 
 class DvbPanel : public KaffeineInput
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
