@@ -25,7 +25,7 @@
 
 #include <tqdir.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include "dvbsi.h"
 
@@ -931,7 +931,7 @@ void DVBsi::out( bool stopscan )
 	}
 	if ( stopscan )
 		dvb->stopScan();
-	KApplication::kApplication()->postEvent( this, new TQTimerEvent( TIMER_EVENT_SCAN_END ) );
+	TDEApplication::kApplication()->postEvent( this, new TQTimerEvent( TIMER_EVENT_SCAN_END ) );
 }
 
 
@@ -1107,7 +1107,7 @@ void DVBsi::run()
 	fprintf(stderr,"dvbsi: The end :)\n");
 	isRunning = false;
 	listChannels();
-	KApplication::kApplication()->postEvent( this, new TQTimerEvent( TIMER_EVENT_SCAN_END ) );
+	TDEApplication::kApplication()->postEvent( this, new TQTimerEvent( TIMER_EVENT_SCAN_END ) );
 }
 
 
