@@ -143,18 +143,18 @@ KEvents::KEvents( TQPtrList<ChannelDesc> *chans, TQPtrList<DvbStream> *d, EventT
 	new EListViewItem( (TQListView*)listView, "Une chaine", "99/99/99  99:99 9999", "99:99 99", "un titre de programme", 0 );
 
 	resize( size );
-	connect( resetBtn			, TQT_SIGNAL( pressed() ), this, TQT_SLOT( reset() ) );
-	connect( allBtn				, TQT_SIGNAL( clicked() ), this, TQT_SLOT( setScheduled() ) );
-	connect( currentNextBtn		, TQT_SIGNAL( clicked() ), this, TQT_SLOT( setCurrentNext() ) );
-	connect( currentChannelEpgBtn, TQT_SIGNAL( clicked() ), this, TQT_SLOT( setCurrentChannelEpg() ) );
-	connect( searchBtn, 		  TQT_SIGNAL( clicked() ), this,	 TQT_SLOT(resetSearch()) );
-	connect( searchLineEdit, TQT_SIGNAL( returnPressed() ), this, TQT_SLOT( epgSearch() ) );
+	connect( resetBtn			, TQ_SIGNAL( pressed() ), this, TQ_SLOT( reset() ) );
+	connect( allBtn				, TQ_SIGNAL( clicked() ), this, TQ_SLOT( setScheduled() ) );
+	connect( currentNextBtn		, TQ_SIGNAL( clicked() ), this, TQ_SLOT( setCurrentNext() ) );
+	connect( currentChannelEpgBtn, TQ_SIGNAL( clicked() ), this, TQ_SLOT( setCurrentChannelEpg() ) );
+	connect( searchBtn, 		  TQ_SIGNAL( clicked() ), this,	 TQ_SLOT(resetSearch()) );
+	connect( searchLineEdit, TQ_SIGNAL( returnPressed() ), this, TQ_SLOT( epgSearch() ) );
 
-	connect( listView, TQT_SIGNAL( mouseButtonClicked(int,TQListViewItem*,const TQPoint&,int) ),
-		this, TQT_SLOT(mouseClickedSlot(int,TQListViewItem*,const TQPoint&,int)) );
+	connect( listView, TQ_SIGNAL( mouseButtonClicked(int,TQListViewItem*,const TQPoint&,int) ),
+		this, TQ_SLOT(mouseClickedSlot(int,TQListViewItem*,const TQPoint&,int)) );
 
-	connect( listView, TQT_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint &,int)),
-		this, TQT_SLOT(zap(TQListViewItem*,const TQPoint &,int)) );
+	connect( listView, TQ_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint &,int)),
+		this, TQ_SLOT(zap(TQListViewItem*,const TQPoint &,int)) );
 
 	setMode( 1 );
         delete icon;
@@ -312,7 +312,7 @@ void KEvents::mouseClickedSlot( int btn, TQListViewItem *it, const TQPoint &p, i
 	EListViewItem *ei = (EListViewItem*)it;
 
 	switch ( btn ) {
-		case Qt::RightButton : {
+		case TQt::RightButton : {
 			TQPopupMenu *pop = new TQPopupMenu();
 			pop->insertItem( i18n("View All Programs"), 1 );
 			pop->insertSeparator();
@@ -334,7 +334,7 @@ void KEvents::mouseClickedSlot( int btn, TQListViewItem *it, const TQPoint &p, i
 			delete pop;
 			break;
 		}
-		case Qt::LeftButton : {
+		case TQt::LeftButton : {
 			s = "<qt><h3><font color=\"darkblue\">";
 			s = s+it->text(0)+"</font></h3>";
 			if ( !ei->event->title.isEmpty() ) {
