@@ -71,8 +71,8 @@ GStreamerConfig::GStreamerConfig(const TQStringList& audioDrivers, const TQStrin
 	layout->addWidget(new TQLabel(TQString("<small>") + i18n("* Restart required!") + "</small>", frame), 10, 1);
 
 	//Media page
-	frame = addPage(i18n("Media"), i18n("Media Options"), TDEGlobal::iconLoader()->loadIcon("media-optical-cdrom", TDEIcon::Panel,
-	                TDEIcon::SizeMedium));
+	frame = addPage(i18n("Media"), i18n("Media Options"), TDEGlobal::iconLoader()->loadIcon("media-optical-cdrom-unmounted",
+	                TDEIcon::Panel, TDEIcon::SizeMedium));
 	layout = new TQGridLayout(frame, 10, 2);
 	layout->setMargin(10);
 	layout->setSpacing(10);
