@@ -120,9 +120,9 @@ XinePart::XinePart(TQWidget* parentWidget, const char* widgetName, TQObject* par
 
 	m_xine = new KXineWidget(parentWidget, widgetName, configPath, logoPath,
 	                         audioDriver, videoDriver, /* start xine manual*/true, verbose);
-	connect(m_xine, TQT_SIGNAL(signalXineFatal(const TQString&)), this, TQT_SIGNAL(canceled(const TQString&)));
-	connect(m_xine, TQT_SIGNAL(stopDvb()), this, TQT_SIGNAL(stopDvb()));
-	connect(m_xine, TQT_SIGNAL(signalDvbOSDHidden()), this, TQT_SIGNAL(dvbOSDHide()));
+	connect(m_xine, TQ_SIGNAL(signalXineFatal(const TQString&)), this, TQ_SIGNAL(canceled(const TQString&)));
+	connect(m_xine, TQ_SIGNAL(stopDvb()), this, TQ_SIGNAL(stopDvb()));
+	connect(m_xine, TQ_SIGNAL(signalDvbOSDHidden()), this, TQ_SIGNAL(dvbOSDHide()));
 	m_xine->setFocusPolicy(TQWidget::ClickFocus);
 	setWidget(m_xine);
 
@@ -131,7 +131,7 @@ XinePart::XinePart(TQWidget* parentWidget, const char* widgetName, TQObject* par
 	initActions();
 	initConnections();
 
-	TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotDisableAllActions()));
+	TQTimer::singleShot(0, this, TQ_SLOT(slotDisableAllActions()));
 	m_oldPosition = m_xine->mapToGlobal(TQPoint(0,0));
 	m_posCheckTimer.start(333);
 }
@@ -314,7 +314,7 @@ void XinePart::slotPlay(bool forcePlay)
 				return;
 		}
 		else
-			TQTimer::singleShot(0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotPlay()));
+			TQTimer::singleShot(0, m_xine, TQ_SLOT(slotPlay()));
 	}
 	else
 	{
@@ -331,7 +331,7 @@ void XinePart::slotPlay(bool forcePlay)
 					return;
 			}
 			else
-				TQTimer::singleShot(0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotPlay()));
+				TQTimer::singleShot(0, m_xine, TQ_SLOT(slotPlay()));
 		}
 		else
 			kdError() << "XinePart: " << TDEIO::NetAccess::lastErrorString() << endl;
@@ -354,7 +354,7 @@ void XinePart::slotStop()
 		m_playlist[m_current] = MRL("dvd://" + TQString::number(title) + "." + TQString::number(chapter));
 	}
 
-	TQTimer::singleShot(0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotStop()));
+	TQTimer::singleShot(0, m_xine, TQ_SLOT(slotStop()));
 	stateChanged("not_playing");
 	m_pauseButton->setChecked(false);
 	m_playTime->setText("0:00:00");
@@ -416,7 +416,7 @@ void XinePart::slotDvbOpen( const TQString &filename, const TQString &chanName,
 			return;
 	m_playlist.clear();
 	m_xine->setDvb( filename, chanName, haveVideo );
-	TQTimer::singleShot(0, TQT_TQOBJECT(m_xine), TQT_SLOT(openDvb()));
+	TQTimer::singleShot(0, m_xine, TQ_SLOT(openDvb()));
 	//m_xine->openDvb( filename, chanName, haveVideo );
 }
 
@@ -588,7 +588,7 @@ void XinePart::slotSaveStream()
 
 	m_xine->clearQueue();
 	m_xine->appendToQueue(m_playlist[m_current].url() + "#save:" + kurl.path());
-	TQTimer::singleShot(0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotPlay()));
+	TQTimer::singleShot(0, m_xine, TQ_SLOT(slotPlay()));
 	m_pauseButton->setChecked(false);
 }
 
@@ -835,14 +835,14 @@ void XinePart::slotFilterDialog()
 	if (!m_filterDialog)
 	{
 		m_filterDialog = new FilterDialog(m_xine->getAudioFilterNames(), m_xine->getVideoFilterNames());
-		connect(m_filterDialog, TQT_SIGNAL(signalCreateAudioFilter(const TQString&, TQWidget*)),
-		        m_xine, TQT_SLOT(slotCreateAudioFilter(const TQString&, TQWidget*)));
-		connect(m_filterDialog, TQT_SIGNAL(signalCreateVideoFilter(const TQString&, TQWidget*)),
-		        m_xine, TQT_SLOT(slotCreateVideoFilter(const TQString&, TQWidget*)));
-		connect(m_filterDialog, TQT_SIGNAL(signalRemoveAllAudioFilters()), TQT_TQOBJECT(m_xine), TQT_SLOT(slotRemoveAllAudioFilters()));
-		connect(m_filterDialog, TQT_SIGNAL(signalRemoveAllVideoFilters()), TQT_TQOBJECT(m_xine), TQT_SLOT(slotRemoveAllVideoFilters()));
-		connect(m_filterDialog, TQT_SIGNAL(signalUseAudioFilters(bool)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotEnableAudioFilters(bool)));
-		connect(m_filterDialog, TQT_SIGNAL(signalUseVideoFilters(bool)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotEnableVideoFilters(bool)));
+		connect(m_filterDialog, TQ_SIGNAL(signalCreateAudioFilter(const TQString&, TQWidget*)),
+		        m_xine, TQ_SLOT(slotCreateAudioFilter(const TQString&, TQWidget*)));
+		connect(m_filterDialog, TQ_SIGNAL(signalCreateVideoFilter(const TQString&, TQWidget*)),
+		        m_xine, TQ_SLOT(slotCreateVideoFilter(const TQString&, TQWidget*)));
+		connect(m_filterDialog, TQ_SIGNAL(signalRemoveAllAudioFilters()), m_xine, TQ_SLOT(slotRemoveAllAudioFilters()));
+		connect(m_filterDialog, TQ_SIGNAL(signalRemoveAllVideoFilters()), m_xine, TQ_SLOT(slotRemoveAllVideoFilters()));
+		connect(m_filterDialog, TQ_SIGNAL(signalUseAudioFilters(bool)), m_xine, TQ_SLOT(slotEnableAudioFilters(bool)));
+		connect(m_filterDialog, TQ_SIGNAL(signalUseVideoFilters(bool)), m_xine, TQ_SLOT(slotEnableVideoFilters(bool)));
 	}
 	m_filterDialog->show();
 	m_filterDialog->raise();
@@ -854,8 +854,8 @@ void XinePart::slotDeinterlaceQuality()
 		return;
 	DeinterlaceQuality* deinterlaceQuality = new DeinterlaceQuality((TQWidget*)m_deinterlacerConfigWidget);
 	deinterlaceQuality->setQuality(m_lastDeinterlaceQuality);
-	connect(deinterlaceQuality, TQT_SIGNAL(signalSetDeinterlaceConfig(const TQString&)),
-	        m_xine, TQT_SLOT(slotSetDeinterlaceConfig(const TQString&)));
+	connect(deinterlaceQuality, TQ_SIGNAL(signalSetDeinterlaceConfig(const TQString&)),
+	        m_xine, TQ_SLOT(slotSetDeinterlaceConfig(const TQString&)));
 
 	deinterlaceQuality->exec();
 
@@ -903,12 +903,12 @@ void XinePart::slotPictureSettings()
 		int hue, sat, contrast, bright, avOffset, spuOffset;
 		m_xine->getVideoSettings(hue, sat, contrast, bright, avOffset, spuOffset);
 		m_pictureSettings = new VideoSettings(hue, sat, contrast, bright, avOffset, spuOffset);
-		connect(m_pictureSettings, TQT_SIGNAL(signalNewHue(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetHue(int)));
-		connect(m_pictureSettings, TQT_SIGNAL(signalNewSaturation(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetSaturation(int)));
-		connect(m_pictureSettings, TQT_SIGNAL(signalNewContrast(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetContrast(int)));
-		connect(m_pictureSettings, TQT_SIGNAL(signalNewBrightness(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetBrightness(int)));
-		connect(m_pictureSettings, TQT_SIGNAL(signalNewAVOffset(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetAVOffset(int)));
-		connect(m_pictureSettings, TQT_SIGNAL(signalNewSpuOffset(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetSpuOffset(int)));
+		connect(m_pictureSettings, TQ_SIGNAL(signalNewHue(int)), this, TQ_SLOT(slotSetHue(int)));
+		connect(m_pictureSettings, TQ_SIGNAL(signalNewSaturation(int)), this, TQ_SLOT(slotSetSaturation(int)));
+		connect(m_pictureSettings, TQ_SIGNAL(signalNewContrast(int)), this, TQ_SLOT(slotSetContrast(int)));
+		connect(m_pictureSettings, TQ_SIGNAL(signalNewBrightness(int)), this, TQ_SLOT(slotSetBrightness(int)));
+		connect(m_pictureSettings, TQ_SIGNAL(signalNewAVOffset(int)), m_xine, TQ_SLOT(slotSetAVOffset(int)));
+		connect(m_pictureSettings, TQ_SIGNAL(signalNewSpuOffset(int)), m_xine, TQ_SLOT(slotSetSpuOffset(int)));
 	}
 	m_pictureSettings->show();
 	m_pictureSettings->raise();
@@ -1073,7 +1073,7 @@ void XinePart::slotTrackPlaying()
 
 	kdDebug() << "XinePart: xine is playing" << endl;
 	m_pauseButton->setChecked(false);
-	TQTimer::singleShot(100, TQT_TQOBJECT(this), TQT_SLOT(slotEnablePlayActions()));
+	TQTimer::singleShot(100, this, TQ_SLOT(slotEnablePlayActions()));
 
 	if ( m_xine->getURL()=="DVB" )
 	{
@@ -1276,9 +1276,9 @@ void XinePart::slotFinalize()
 		actionCollection()->action("file_save_screenshot")->plug(m_embeddedContext);
 		actionCollection()->action("file_save_stream")->plug(m_embeddedContext);
 		m_embeddedContext->insertSeparator();
-		action = new TDEAction(i18n("Copy URL to Clipboard"), "edit-copy", 0, TQT_TQOBJECT(this), TQT_SLOT(slotCopyToClipboard()), actionCollection(), "copy_to_clipboard");
+		action = new TDEAction(i18n("Copy URL to Clipboard"), "edit-copy", 0, this, TQ_SLOT(slotCopyToClipboard()), actionCollection(), "copy_to_clipboard");
 		action->plug(m_embeddedContext);
-		action = new TDEAction(i18n("Play in Kaffeine Externally"), "gear", 0, TQT_TQOBJECT(this), TQT_SLOT(slotLaunchExternally()), actionCollection(), "play_externally");
+		action = new TDEAction(i18n("Play in Kaffeine Externally"), "gear", 0, this, TQ_SLOT(slotLaunchExternally()), actionCollection(), "play_externally");
 		action->plug(m_embeddedContext);
 	}
 
@@ -1287,7 +1287,7 @@ void XinePart::slotFinalize()
 	m_audioVisual->setItems(visuals);
 
 	loadConfig();
-	TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotEnableAllActions()));
+	TQTimer::singleShot(0, this, TQ_SLOT(slotEnableAllActions()));
 }
 
 void XinePart::slotCopyToClipboard()
@@ -1302,7 +1302,7 @@ void XinePart::slotLaunchExternally()
 {
 	slotStop();
 
-	TQTimer::singleShot(1000, TQT_TQOBJECT(this), TQT_SLOT(slotLaunchDelayed()));
+	TQTimer::singleShot(1000, this, TQ_SLOT(slotLaunchDelayed()));
 }
 
 void XinePart::slotLaunchDelayed()
@@ -1319,98 +1319,98 @@ void XinePart::initActions()
 {
 	TDEAction* action = NULL;
 	/* file menu */
-	m_broadcastSend = new TDEToggleAction(i18n("&Send Broadcast Stream..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotToggleBroadcastSend()), actionCollection(), "network_send");
-	new TDEAction(i18n("&Receive Broadcast Stream..."), "network", 0, TQT_TQOBJECT(this), TQT_SLOT(slotBroadcastReceive()), actionCollection(), "network_receive");
-	new TDEAction(i18n("&Save Screenshot..."), "frame_image", CTRL|Key_S, TQT_TQOBJECT(this), TQT_SLOT(slotScreenshot()), actionCollection(), "file_save_screenshot");
-	action = new TDEAction(i18n("Save Stream..."), "player_record", Key_R, TQT_TQOBJECT(this), TQT_SLOT(slotSaveStream()), actionCollection(), "file_save_stream");
+	m_broadcastSend = new TDEToggleAction(i18n("&Send Broadcast Stream..."), 0, 0, this, TQ_SLOT(slotToggleBroadcastSend()), actionCollection(), "network_send");
+	new TDEAction(i18n("&Receive Broadcast Stream..."), "network", 0, this, TQ_SLOT(slotBroadcastReceive()), actionCollection(), "network_receive");
+	new TDEAction(i18n("&Save Screenshot..."), "frame_image", CTRL|Key_S, this, TQ_SLOT(slotScreenshot()), actionCollection(), "file_save_screenshot");
+	action = new TDEAction(i18n("Save Stream..."), "player_record", Key_R, this, TQ_SLOT(slotSaveStream()), actionCollection(), "file_save_stream");
 	action->setWhatsThis(i18n("Saves current stream to harddisc. This feature was disabled for some formats (e.g. Real Media) to prevent potential legal problems."));
 
 	/* player menu */
 
-	new TDEAction(i18n("Toggle Minimal Mode"), 0, 0, this, TQT_SIGNAL(signalToggleMinimalMode()), actionCollection(), "player_minimal_mode");
+	new TDEAction(i18n("Toggle Minimal Mode"), 0, 0, this, TQ_SIGNAL(signalToggleMinimalMode()), actionCollection(), "player_minimal_mode");
 
-	new TDEAction(i18n("Play"), "media-playback-start", 0, TQT_TQOBJECT(this), TQT_SLOT(slotPlay()), actionCollection(), "player_play");
-	m_pauseButton = new TDEToggleAction(i18n("Pause"), "media-playback-pause", Key_Space, TQT_TQOBJECT(this), TQT_SLOT(slotTogglePause()), actionCollection(), "player_pause");
-	new TDEAction(i18n("&Next"), "media-skip-forward", Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotNext()), actionCollection(), "player_next");
-	new TDEAction(i18n("&Previous"), "media-skip-backward", Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPrevious()), actionCollection(), "player_previous");
-	new TDEAction(i18n("Stop"), "media-playback-stop", Key_Backspace, TQT_TQOBJECT(this), TQT_SLOT(slotStop()), actionCollection(), "player_stop");
+	new TDEAction(i18n("Play"), "media-playback-start", 0, this, TQ_SLOT(slotPlay()), actionCollection(), "player_play");
+	m_pauseButton = new TDEToggleAction(i18n("Pause"), "media-playback-pause", Key_Space, this, TQ_SLOT(slotTogglePause()), actionCollection(), "player_pause");
+	new TDEAction(i18n("&Next"), "media-skip-forward", Key_PageDown, this, TQ_SLOT(slotNext()), actionCollection(), "player_next");
+	new TDEAction(i18n("&Previous"), "media-skip-backward", Key_PageUp, this, TQ_SLOT(slotPrevious()), actionCollection(), "player_previous");
+	new TDEAction(i18n("Stop"), "media-playback-stop", Key_Backspace, this, TQ_SLOT(slotStop()), actionCollection(), "player_stop");
 
-	new TDEAction(i18n("&Fast Forward"), "media-seek-forward", ALT|Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotFastForward()), actionCollection(), "player_ff");
-	new TDEAction(i18n("Slow &Motion"), 0, ALT|Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotSlowMotion()), actionCollection(), "player_slowmotion");
+	new TDEAction(i18n("&Fast Forward"), "media-seek-forward", ALT|Key_Right, this, TQ_SLOT(slotFastForward()), actionCollection(), "player_ff");
+	new TDEAction(i18n("Slow &Motion"), 0, ALT|Key_Left, this, TQ_SLOT(slotSlowMotion()), actionCollection(), "player_slowmotion");
 
-	new TDEAction(i18n("Skip Forward (20s)"), NULL, Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotPosPlusSmall()), actionCollection(), "player_posplus_small");
-	new TDEAction(i18n("Skip Backward (20s)"), NULL, Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotPosMinusSmall()), actionCollection(), "player_posminus_small");
-	new TDEAction(i18n("Skip Forward (1m)"), NULL, CTRL|Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPosPlusMedium()), actionCollection(), "player_posplus_medium");
-	new TDEAction(i18n("Skip Backward (1m)"), NULL, CTRL|Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotPosMinusMedium()), actionCollection(), "player_posminus_medium");
-	new TDEAction(i18n("Skip Forward (10m)"), NULL, ALT|Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPosPlusLarge()), actionCollection(), "player_posplus_large");
-	new TDEAction(i18n("Skip Backward (10m)"), NULL, ALT|Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotPosMinusLarge()), actionCollection(), "player_posminus_large");
-	new TDEAction(i18n("Jump to Position..."), "goto", CTRL|Key_J, TQT_TQOBJECT(this), TQT_SLOT(slotJumpToPosition()), actionCollection(), "player_jump_to");
+	new TDEAction(i18n("Skip Forward (20s)"), NULL, Key_Right, this, TQ_SLOT(slotPosPlusSmall()), actionCollection(), "player_posplus_small");
+	new TDEAction(i18n("Skip Backward (20s)"), NULL, Key_Left, this, TQ_SLOT(slotPosMinusSmall()), actionCollection(), "player_posminus_small");
+	new TDEAction(i18n("Skip Forward (1m)"), NULL, CTRL|Key_PageUp, this, TQ_SLOT(slotPosPlusMedium()), actionCollection(), "player_posplus_medium");
+	new TDEAction(i18n("Skip Backward (1m)"), NULL, CTRL|Key_PageDown, this, TQ_SLOT(slotPosMinusMedium()), actionCollection(), "player_posminus_medium");
+	new TDEAction(i18n("Skip Forward (10m)"), NULL, ALT|Key_PageUp, this, TQ_SLOT(slotPosPlusLarge()), actionCollection(), "player_posplus_large");
+	new TDEAction(i18n("Skip Backward (10m)"), NULL, ALT|Key_PageDown, this, TQ_SLOT(slotPosMinusLarge()), actionCollection(), "player_posminus_large");
+	new TDEAction(i18n("Jump to Position..."), "goto", CTRL|Key_J, this, TQ_SLOT(slotJumpToPosition()), actionCollection(), "player_jump_to");
 
-	new TDEAction(i18n("DVD Menu Left"), 0, CTRL|Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuLeft()), actionCollection(), "dvdmenuleft");
-	new TDEAction(i18n("DVD Menu Right"), 0, CTRL|Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuRight()), actionCollection(), "dvdmenuright");
-	new TDEAction(i18n("DVD Menu Up"), 0, CTRL|Key_Up, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuUp()), actionCollection(), "dvdmenuup");
-	new TDEAction(i18n("DVD Menu Down"), 0, CTRL|Key_Down, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuDown()), actionCollection(), "dvdmenudown");
-	new TDEAction(i18n("DVD Menu Select"), 0, CTRL|Key_Return, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuSelect()), actionCollection(), "dvdmenuselect");
+	new TDEAction(i18n("DVD Menu Left"), 0, CTRL|Key_Left, this, TQ_SLOT(slotDVDMenuLeft()), actionCollection(), "dvdmenuleft");
+	new TDEAction(i18n("DVD Menu Right"), 0, CTRL|Key_Right, this, TQ_SLOT(slotDVDMenuRight()), actionCollection(), "dvdmenuright");
+	new TDEAction(i18n("DVD Menu Up"), 0, CTRL|Key_Up, this, TQ_SLOT(slotDVDMenuUp()), actionCollection(), "dvdmenuup");
+	new TDEAction(i18n("DVD Menu Down"), 0, CTRL|Key_Down, this, TQ_SLOT(slotDVDMenuDown()), actionCollection(), "dvdmenudown");
+	new TDEAction(i18n("DVD Menu Select"), 0, CTRL|Key_Return, this, TQ_SLOT(slotDVDMenuSelect()), actionCollection(), "dvdmenuselect");
 
 	m_audioChannels = new TDESelectAction(i18n("Audio Channel"), 0, actionCollection(), "audio_channels");
 	m_audioChannels->setToolTip(i18n("Select audio channel"));
 	m_audioChannels->setComboWidth( 50 );
-	connect(m_audioChannels, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetAudioChannel(int )));
-	new TDEAction(i18n("&Next Audio Channel"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotNextAudioChannel()), actionCollection(), "next_audio_channels");
+	connect(m_audioChannels, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotSetAudioChannel(int )));
+	new TDEAction(i18n("&Next Audio Channel"), 0, 0, this, TQ_SLOT(slotNextAudioChannel()), actionCollection(), "next_audio_channels");
 	m_audioVisual = new TDESelectAction(i18n("Audio &Visualization"), 0, actionCollection(), "audio_visualization");
-	connect(m_audioVisual, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetVisualPlugin(const TQString&)));
-	new TDEAction(i18n("&Mute"), "player_mute", Key_U, TQT_TQOBJECT(this), TQT_SLOT(slotMute()), actionCollection(), "audio_mute");
-	new TDEAction(i18n("Volume Up"), NULL, Key_Plus, TQT_TQOBJECT(this), TQT_SLOT(slotVolumeUp()), actionCollection(), "volume_increase");
-	new TDEAction(i18n("Volume Down"), NULL, Key_Minus, TQT_TQOBJECT(this), TQT_SLOT(slotVolumeDown()), actionCollection(), "volume_decrease");
+	connect(m_audioVisual, TQ_SIGNAL(activated(const TQString&)), m_xine, TQ_SLOT(slotSetVisualPlugin(const TQString&)));
+	new TDEAction(i18n("&Mute"), "player_mute", Key_U, this, TQ_SLOT(slotMute()), actionCollection(), "audio_mute");
+	new TDEAction(i18n("Volume Up"), NULL, Key_Plus, this, TQ_SLOT(slotVolumeUp()), actionCollection(), "volume_increase");
+	new TDEAction(i18n("Volume Down"), NULL, Key_Minus, this, TQ_SLOT(slotVolumeDown()), actionCollection(), "volume_decrease");
 
-	m_deinterlaceEnabled = new TDEToggleAction(i18n("&Deinterlace"), 0, Key_I, TQT_TQOBJECT(m_xine), TQT_SLOT(slotToggleDeinterlace()), actionCollection(), "video_deinterlace");
+	m_deinterlaceEnabled = new TDEToggleAction(i18n("&Deinterlace"), 0, Key_I, m_xine, TQ_SLOT(slotToggleDeinterlace()), actionCollection(), "video_deinterlace");
 	m_deinterlaceEnabled->setWhatsThis(i18n("Activate this for interlaced streams, some DVD's for example."));
-	new TDEAction(i18n("&Auto"), "zoom-fit-best", Key_F5, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioAuto()), actionCollection(), "aspect_auto");
-	new TDEAction(i18n("&4:3"), "zoom-fit-best", Key_F6, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatio4_3()), actionCollection(), "aspect_43");
-	new TDEAction(i18n("A&namorphic"), "zoom-fit-best", Key_F7, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioAnamorphic()), actionCollection(), "aspect_anamorphic");
-	new TDEAction(i18n("&DVB"), "zoom-fit-best", Key_F8, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioDVB()), actionCollection(), "aspect_dvb");
-	new TDEAction(i18n("&Square"), "zoom-fit-best", Key_F9, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioSquare()), actionCollection(), "aspect_square");
-	KStdAction::zoomIn(TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomIn()), actionCollection(), "zoom_in");
-	KStdAction::zoomOut(TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOut()), actionCollection(), "zoom_out");
-	KStdAction::fitToPage(TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOff()), actionCollection(), "zoom_off");
-	new TDEAction(i18n("Zoom In Horizontal"), NULL, CTRL|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInX()), actionCollection(), "zoom_in_x");
-	new TDEAction(i18n("Zoom Out Horizontal"), NULL, CTRL|SHIFT|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutX()), actionCollection(), "zoom_out_x");
-	new TDEAction(i18n("Zoom In Vertical"), NULL, CTRL|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInY()), actionCollection(), "zoom_in_y");
-	new TDEAction(i18n("Zoom Out Vertical"), NULL, CTRL|SHIFT|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutY()), actionCollection(), "zoom_out_y");
-	new TDEAction(i18n("Deinterlace &Quality"), "blend", CTRL|Key_I, TQT_TQOBJECT(this), TQT_SLOT(slotDeinterlaceQuality()), actionCollection(), "video_deinterlace_quality");
-	new TDEAction(i18n("&Video Settings"), "configure", Key_V, TQT_TQOBJECT(this), TQT_SLOT(slotPictureSettings()), actionCollection(), "video_picture");
-	new TDEAction(i18n("&Equalizer"), NULL, Key_E, TQT_TQOBJECT(this), TQT_SLOT(slotEqualizer()), actionCollection(), "equalizer");
+	new TDEAction(i18n("&Auto"), "zoom-fit-best", Key_F5, m_xine, TQ_SLOT(slotAspectRatioAuto()), actionCollection(), "aspect_auto");
+	new TDEAction(i18n("&4:3"), "zoom-fit-best", Key_F6, m_xine, TQ_SLOT(slotAspectRatio4_3()), actionCollection(), "aspect_43");
+	new TDEAction(i18n("A&namorphic"), "zoom-fit-best", Key_F7, m_xine, TQ_SLOT(slotAspectRatioAnamorphic()), actionCollection(), "aspect_anamorphic");
+	new TDEAction(i18n("&DVB"), "zoom-fit-best", Key_F8, m_xine, TQ_SLOT(slotAspectRatioDVB()), actionCollection(), "aspect_dvb");
+	new TDEAction(i18n("&Square"), "zoom-fit-best", Key_F9, m_xine, TQ_SLOT(slotAspectRatioSquare()), actionCollection(), "aspect_square");
+	KStdAction::zoomIn(m_xine, TQ_SLOT(slotZoomIn()), actionCollection(), "zoom_in");
+	KStdAction::zoomOut(m_xine, TQ_SLOT(slotZoomOut()), actionCollection(), "zoom_out");
+	KStdAction::fitToPage(m_xine, TQ_SLOT(slotZoomOff()), actionCollection(), "zoom_off");
+	new TDEAction(i18n("Zoom In Horizontal"), NULL, CTRL|Key_H, m_xine, TQ_SLOT(slotZoomInX()), actionCollection(), "zoom_in_x");
+	new TDEAction(i18n("Zoom Out Horizontal"), NULL, CTRL|SHIFT|Key_H, m_xine, TQ_SLOT(slotZoomOutX()), actionCollection(), "zoom_out_x");
+	new TDEAction(i18n("Zoom In Vertical"), NULL, CTRL|Key_V, m_xine, TQ_SLOT(slotZoomInY()), actionCollection(), "zoom_in_y");
+	new TDEAction(i18n("Zoom Out Vertical"), NULL, CTRL|SHIFT|Key_V, m_xine, TQ_SLOT(slotZoomOutY()), actionCollection(), "zoom_out_y");
+	new TDEAction(i18n("Deinterlace &Quality"), "blend", CTRL|Key_I, this, TQ_SLOT(slotDeinterlaceQuality()), actionCollection(), "video_deinterlace_quality");
+	new TDEAction(i18n("&Video Settings"), "configure", Key_V, this, TQ_SLOT(slotPictureSettings()), actionCollection(), "video_picture");
+	new TDEAction(i18n("&Equalizer"), NULL, Key_E, this, TQ_SLOT(slotEqualizer()), actionCollection(), "equalizer");
 
 
 	m_subtitles = new TDESelectAction(i18n("Subtitle"), 0, actionCollection(), "player_subtitles");
 	m_subtitles->setToolTip(i18n("Select Subtitle"));
 	m_subtitles->setComboWidth( 50 );
-	connect(m_subtitles, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetSubtitle(int)));
-	new TDEAction(i18n("&Next Subtitle Channel"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotNextSubtitleChannel()), actionCollection(), "next_player_subtitles");
-	new TDEAction(i18n("Delay Subtitle"), 0, CTRL|ALT|Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotDelaySubTitle()), actionCollection(), "adv_sub");
-	new TDEAction(i18n("Advance Subtitle"), 0, CTRL|ALT|Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotAdvanceSubTitle()), actionCollection(), "delay_sub");
-	new TDEAction(i18n("Add subtitle..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotAddSubtitle()), actionCollection(), "add_subtitle");
+	connect(m_subtitles, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotSetSubtitle(int)));
+	new TDEAction(i18n("&Next Subtitle Channel"), 0, 0, this, TQ_SLOT(slotNextSubtitleChannel()), actionCollection(), "next_player_subtitles");
+	new TDEAction(i18n("Delay Subtitle"), 0, CTRL|ALT|Key_Left, this, TQ_SLOT(slotDelaySubTitle()), actionCollection(), "adv_sub");
+	new TDEAction(i18n("Advance Subtitle"), 0, CTRL|ALT|Key_Right, this, TQ_SLOT(slotAdvanceSubTitle()), actionCollection(), "delay_sub");
+	new TDEAction(i18n("Add subtitle..."), 0, 0, this, TQ_SLOT(slotAddSubtitle()), actionCollection(), "add_subtitle");
 
-	new TDEAction(i18n("&Menu Toggle"), "view_detailed", Key_D, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuToggle()), actionCollection(), "dvd_toggle");
-	new TDEAction(i18n("&Title"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuTitle()), actionCollection(), "dvd_title");
-	new TDEAction(i18n("&Root"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuRoot()), actionCollection(), "dvd_root");
-	new TDEAction(i18n("&Subpicture"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuSubpicture()), actionCollection(), "dvd_subpicture");
-	new TDEAction(i18n("&Audio"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuAudio()), actionCollection(), "dvd_audio");
-	new TDEAction(i18n("An&gle"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuAngle()), actionCollection(), "dvd_angle");
-	new TDEAction(i18n("&Part"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuPart()), actionCollection(), "dvd_part");
+	new TDEAction(i18n("&Menu Toggle"), "view_detailed", Key_D, m_xine, TQ_SLOT(slotMenuToggle()), actionCollection(), "dvd_toggle");
+	new TDEAction(i18n("&Title"), NULL, 0, m_xine, TQ_SLOT(slotMenuTitle()), actionCollection(), "dvd_title");
+	new TDEAction(i18n("&Root"), NULL, 0, m_xine, TQ_SLOT(slotMenuRoot()), actionCollection(), "dvd_root");
+	new TDEAction(i18n("&Subpicture"), NULL, 0, m_xine, TQ_SLOT(slotMenuSubpicture()), actionCollection(), "dvd_subpicture");
+	new TDEAction(i18n("&Audio"), NULL, 0, m_xine, TQ_SLOT(slotMenuAudio()), actionCollection(), "dvd_audio");
+	new TDEAction(i18n("An&gle"), NULL, 0, m_xine, TQ_SLOT(slotMenuAngle()), actionCollection(), "dvd_angle");
+	new TDEAction(i18n("&Part"), NULL, 0, m_xine, TQ_SLOT(slotMenuPart()), actionCollection(), "dvd_part");
 
 	m_dvdTitles = new TDESelectAction(i18n("Titles"), 0, actionCollection(), "dvd_title_menu");
-	connect(m_dvdTitles, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotSetDVDTitle(const TQString&)));
+	connect(m_dvdTitles, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(slotSetDVDTitle(const TQString&)));
 	m_dvdChapters = new TDESelectAction(i18n("Chapters"), 0, actionCollection(), "dvd_chapter_menu");
-	connect(m_dvdChapters, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotSetDVDChapter(const TQString&)));
+	connect(m_dvdChapters, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(slotSetDVDChapter(const TQString&)));
 	m_dvdAngles = new TDESelectAction(i18n("Angles"), 0, actionCollection(), "dvd_angle_menu");
-	connect(m_dvdAngles, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotSetDVDAngle(const TQString&)));
+	connect(m_dvdAngles, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(slotSetDVDAngle(const TQString&)));
 
-	new TDEAction(i18n("Track &Info"), "application-vnd.tde.info", 0 , TQT_TQOBJECT(this), TQT_SLOT(slotInfo()), actionCollection(), "player_track_info");
-	new TDEAction(i18n("Effect &Plugins..."), "filter", Key_X, TQT_TQOBJECT(this), TQT_SLOT(slotFilterDialog()), actionCollection(), "player_post_filters");
+	new TDEAction(i18n("Track &Info"), "application-vnd.tde.info", 0 , this, TQ_SLOT(slotInfo()), actionCollection(), "player_track_info");
+	new TDEAction(i18n("Effect &Plugins..."), "filter", Key_X, this, TQ_SLOT(slotFilterDialog()), actionCollection(), "player_post_filters");
 
 	/* settings menu */
-	new TDEAction(i18n("&xine Engine Parameters"), "edit", 0, TQT_TQOBJECT(this), TQT_SLOT(slotConfigXine()), actionCollection(), "settings_xine_parameter");
+	new TDEAction(i18n("&xine Engine Parameters"), "edit", 0, this, TQ_SLOT(slotConfigXine()), actionCollection(), "settings_xine_parameter");
 
 	m_volume = new VolumeSlider();
 	TQToolTip::add
@@ -1419,8 +1419,8 @@ void XinePart::initActions()
 	m_volume->setSteps(1, 10);
 	m_volume->setFocusPolicy(TQWidget::NoFocus);
 	m_volume->setFixedWidth(75);
-	connect(m_volume, TQT_SIGNAL(valueChanged(int)), TQT_TQOBJECT(this), TQT_SLOT(slotVolumeChanged(int)));
-	connect(m_xine, TQT_SIGNAL(signalSyncVolume()), TQT_TQOBJECT(this), TQT_SLOT(slotSyncVolume()));
+	connect(m_volume, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotVolumeChanged(int)));
+	connect(m_xine, TQ_SIGNAL(signalSyncVolume()), this, TQ_SLOT(slotSyncVolume()));
 	new KWidgetAction(m_volume, i18n("Volume"), 0, 0, 0, actionCollection(), "audio_volume");
 
 	m_position = new PositionSlider(Horizontal);
@@ -1431,10 +1431,10 @@ void XinePart::initActions()
 	m_position->setTracking(false);
 	m_position->setFocusPolicy(TQWidget::NoFocus);
 	m_position->setMinimumWidth(180);
-	connect(m_position, TQT_SIGNAL(sliderMoved(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSeekToPosition(int)));
-	connect(m_position, TQT_SIGNAL(sliderLastMove(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSeekToPositionBlocking(int)));
-	connect(m_position, TQT_SIGNAL(signalStartSeeking()), TQT_TQOBJECT(m_xine), TQT_SLOT(slotStartSeeking()));
-	connect(m_position, TQT_SIGNAL(signalStopSeeking()), TQT_TQOBJECT(m_xine), TQT_SLOT(slotStopSeeking()));
+	connect(m_position, TQ_SIGNAL(sliderMoved(int)), m_xine, TQ_SLOT(slotSeekToPosition(int)));
+	connect(m_position, TQ_SIGNAL(sliderLastMove(int)), m_xine, TQ_SLOT(slotSeekToPositionBlocking(int)));
+	connect(m_position, TQ_SIGNAL(signalStartSeeking()), m_xine, TQ_SLOT(slotStartSeeking()));
+	connect(m_position, TQ_SIGNAL(signalStopSeeking()), m_xine, TQ_SLOT(slotStopSeeking()));
 	new KWidgetAction(m_position, i18n("Position"), 0, 0, 0, actionCollection(), "player_position");
 
 	m_playTime = new TQPushButton(0);
@@ -1445,42 +1445,42 @@ void XinePart::initActions()
 	m_playTime->setSizePolicy(TQSizePolicy (TQSizePolicy::Fixed, TQSizePolicy::Fixed));
 	m_playTime->setFocusPolicy(TQWidget::NoFocus);
 	new KWidgetAction(m_playTime, i18n("Playtime"), 0, 0, 0, actionCollection(), "player_playtime");
-	connect(m_playTime, TQT_SIGNAL(pressed()), TQT_TQOBJECT(this), TQT_SLOT(slotButtonTimerPressed()));
-	connect(m_playTime, TQT_SIGNAL(released()), TQT_TQOBJECT(this), TQT_SLOT(slotButtonTimerReleased()));
+	connect(m_playTime, TQ_SIGNAL(pressed()), this, TQ_SLOT(slotButtonTimerPressed()));
+	connect(m_playTime, TQ_SIGNAL(released()), this, TQ_SLOT(slotButtonTimerReleased()));
 	m_playTime->setText("0:00:00");
 
 	m_equalizer = new Equalizer();
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq30(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq30(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq60(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq60(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq125(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq125(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq250(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq250(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq500(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq500(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq1k(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq1k(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq2k(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq2k(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq4k(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq4k(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq8k(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq8k(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalNewEq16k(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetEq16k(int)));
-	connect(m_equalizer, TQT_SIGNAL(signalSetVolumeGain(bool)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetVolumeGain(bool)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq30(int)), m_xine, TQ_SLOT(slotSetEq30(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq60(int)), m_xine, TQ_SLOT(slotSetEq60(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq125(int)), m_xine, TQ_SLOT(slotSetEq125(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq250(int)), m_xine, TQ_SLOT(slotSetEq250(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq500(int)), m_xine, TQ_SLOT(slotSetEq500(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq1k(int)), m_xine, TQ_SLOT(slotSetEq1k(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq2k(int)), m_xine, TQ_SLOT(slotSetEq2k(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq4k(int)), m_xine, TQ_SLOT(slotSetEq4k(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq8k(int)), m_xine, TQ_SLOT(slotSetEq8k(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalNewEq16k(int)), m_xine, TQ_SLOT(slotSetEq16k(int)));
+	connect(m_equalizer, TQ_SIGNAL(signalSetVolumeGain(bool)), m_xine, TQ_SLOT(slotSetVolumeGain(bool)));
 
 }
 
 void XinePart::initConnections()
 {
-	connect(&m_posCheckTimer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(slotCheckMoved()));
-	connect(&m_osdTimerEnabler, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(slotToggleOsdTimer()));
-	connect(m_xine, TQT_SIGNAL(signalXineReady()), TQT_TQOBJECT(this), TQT_SLOT(slotFinalize()));
-	connect(m_xine, TQT_SIGNAL(signalNewChannels(const TQStringList&, const TQStringList&, int, int )),
-	        this, TQT_SLOT(slotChannelInfo(const TQStringList&, const TQStringList&, int, int )));
-	connect(m_xine, TQT_SIGNAL(signalXinePlaying()), TQT_TQOBJECT(this), TQT_SLOT(slotTrackPlaying()));
-	connect(m_xine, TQT_SIGNAL(signalNewPosition(int, const TQTime&)), TQT_TQOBJECT(this), TQT_SLOT(slotNewPosition(int, const TQTime&)));
-	connect(m_xine, TQT_SIGNAL(signalXineStatus(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotStatus(const TQString&)));
-	connect(m_xine, TQT_SIGNAL(signalXineError(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotError(const TQString&)));
-	connect(m_xine, TQT_SIGNAL(signalXineMessage(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotMessage(const TQString&)));
-	connect(m_xine, TQT_SIGNAL(signalPlaybackFinished()), TQT_TQOBJECT(this), TQT_SLOT(slotPlaybackFinished()));
-	connect(m_xine, TQT_SIGNAL(signalTitleChanged()), TQT_TQOBJECT(this), TQT_SLOT(slotNewTitle()));
-	connect(m_xine, TQT_SIGNAL(signalLengthChanged()), TQT_TQOBJECT(this), TQT_SLOT(slotNewLength()));
-	connect(m_xine, TQT_SIGNAL(signalVideoSizeChanged()), TQT_TQOBJECT(this), TQT_SLOT(slotNewFrameSize()));
-	connect(m_xine, TQT_SIGNAL(signalRightClick(const TQPoint&)), TQT_TQOBJECT(this), TQT_SLOT(slotContextMenu(const TQPoint&)));
+	connect(&m_posCheckTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotCheckMoved()));
+	connect(&m_osdTimerEnabler, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotToggleOsdTimer()));
+	connect(m_xine, TQ_SIGNAL(signalXineReady()), this, TQ_SLOT(slotFinalize()));
+	connect(m_xine, TQ_SIGNAL(signalNewChannels(const TQStringList&, const TQStringList&, int, int )),
+	        this, TQ_SLOT(slotChannelInfo(const TQStringList&, const TQStringList&, int, int )));
+	connect(m_xine, TQ_SIGNAL(signalXinePlaying()), this, TQ_SLOT(slotTrackPlaying()));
+	connect(m_xine, TQ_SIGNAL(signalNewPosition(int, const TQTime&)), this, TQ_SLOT(slotNewPosition(int, const TQTime&)));
+	connect(m_xine, TQ_SIGNAL(signalXineStatus(const TQString&)), this, TQ_SLOT(slotStatus(const TQString&)));
+	connect(m_xine, TQ_SIGNAL(signalXineError(const TQString&)), this, TQ_SLOT(slotError(const TQString&)));
+	connect(m_xine, TQ_SIGNAL(signalXineMessage(const TQString&)), this, TQ_SLOT(slotMessage(const TQString&)));
+	connect(m_xine, TQ_SIGNAL(signalPlaybackFinished()), this, TQ_SLOT(slotPlaybackFinished()));
+	connect(m_xine, TQ_SIGNAL(signalTitleChanged()), this, TQ_SLOT(slotNewTitle()));
+	connect(m_xine, TQ_SIGNAL(signalLengthChanged()), this, TQ_SLOT(slotNewLength()));
+	connect(m_xine, TQ_SIGNAL(signalVideoSizeChanged()), this, TQ_SLOT(slotNewFrameSize()));
+	connect(m_xine, TQ_SIGNAL(signalRightClick(const TQPoint&)), this, TQ_SLOT(slotContextMenu(const TQPoint&)));
 }
 
 void XinePart::loadConfig()
@@ -1830,6 +1830,7 @@ TQString XinePart::supportedExtensions()
 		return TQString();
 
 	TQString ext  = m_xine->getSupportedExtensions();
+	ext = ext.remove(TQRegExp("[A-Za-z]+:[/]+"));
 	ext = ext.remove("txt");
 	ext = "*." + ext;
 	ext.append(" smil");
